==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/ability/impl/specific/WitherAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1687;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import tocraft.walkers.ability.ShapeAbility;

public class WitherAbility<T extends class_1308> extends ShapeAbility<T> {

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        world.method_8465(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14588, class_3419.field_15254, 0.5F, 0.4F / (world.field_9229.nextFloat() * 0.4F + 0.8F));

        if (!world.field_9236) {
            class_243 lookDirection = player.method_5720();
            //#if MC>1206
            class_1687 skull = new class_1687(world, player, new class_243(lookDirection.field_1352, lookDirection.field_1351, lookDirection.field_1350));
            //#else
            //$$ WitherSkull skull = new WitherSkull(world, player, lookDirection.x, lookDirection.y, lookDirection.z);
            //#endif
            skull.method_23327(player.method_23317(), player.method_23318() + 2, player.method_23321());
            skull.method_24919(player, player.method_36455(), player.method_36454(), 0.0F, 1.5F, 1.0F);
            world.method_8649(skull);
        }
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8791;
    }

    @Override
    public int getDefaultCooldown() {
        return 200;
    }
}

==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/ability/impl/specific/WitherAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1687;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import tocraft.walkers.ability.ShapeAbility;

public class WitherAbility<T extends class_1308> extends ShapeAbility<T> {

    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14588, class_3419.field_15254, 0.5F, 0.4F / (world.field_9229.method_43057() * 0.4F + 0.8F));

        if (!world.field_9236) {
            class_243 lookDirection = player.method_5720();
            //#if MC>1206
            class_1687 skull = new class_1687(world, player, new class_243(lookDirection.field_1352, lookDirection.field_1351, lookDirection.field_1350));
            //#else
            //$$ WitherSkull skull = new WitherSkull(world, player, lookDirection.x, lookDirection.y, lookDirection.z);
            //#endif
            skull.method_23327(player.method_23317(), player.method_23318() + 2, player.method_23321());
            skull.method_24919(player, player.method_36455(), player.method_36454(), 0.0F, 1.5F, 1.0F);
            world.method_8649(skull);
        }
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8791;
    }

    @Override
    public int getDefaultCooldown() {
        return 200;
    }
}
